/*== Rohde & Schwarz SMY Include File =====================================*/
#ifndef __RSSMY_HEADER
#define __RSSMY_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define RSSMY_ERROR_INSTR_SPECIFIC      		(VI_ERROR_INSTR_OFFSET + 0xF0L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssmy_init (ViRsrc GPIBAddress, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rssmy_outputWaveform (ViSession instrSession,
                                        ViReal64 radioFreq, ViReal64 audioFreq,
                                        ViReal64 rfLevel, ViBoolean rfLevelUnits,
                                        ViBoolean rfLevelType, ViBoolean rfOutput,
                                        ViBoolean afOutput);
ViStatus _VI_FUNC rssmy_setRF (ViSession instrSession, ViReal64 RF);
ViStatus _VI_FUNC rssmy_setRFLevel (ViSession instrSession, ViReal64 RFLevel,
                                    ViBoolean RFLevelUnits, ViBoolean RFLevelType);
ViStatus _VI_FUNC rssmy_setAF (ViSession instrSession, ViReal64 afValue);
ViStatus _VI_FUNC rssmy_specialSetting (ViSession instrSession,
                                        ViBoolean refFreq, ViBoolean nonInter);
ViStatus _VI_FUNC rssmy_setAMMod (ViSession instrSession,
                                  ViInt32 amType, ViReal64 amDepth);
ViStatus _VI_FUNC rssmy_setFMMod (ViSession instrSession,
                                  ViInt32 frqType, ViReal64 fmDeviation);
ViStatus _VI_FUNC rssmy_setPMMod (ViSession instrSession, ViInt32 pulseType);
ViStatus _VI_FUNC rssmy_setPhMMod (ViSession instrSession,
                                   ViInt32 phMType, ViReal64 phMDeviation);
ViStatus _VI_FUNC rssmy_setFreqLevelStep (ViSession instrSession,
                                          ViReal64 rfStep, ViReal64 afStep,
                                          ViReal64 levelStep);
ViStatus _VI_FUNC rssmy_setModulationStep (ViSession instrSession,
                                           ViReal64 AMStep, ViReal64 FMStep,
                                           ViReal64 phaseModStep);
ViStatus _VI_FUNC rssmy_rfOut (ViSession instrSession, ViBoolean rfOutput);
ViStatus _VI_FUNC rssmy_afOut (ViSession instrSession, ViBoolean afOutput);
ViStatus _VI_FUNC rssmy_singleVarStep (ViSession instrSession,
                                       ViInt32 parameter, ViBoolean direction);
ViStatus _VI_FUNC rssmy_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssmy_readInstrData (ViSession instrumentHandle,
                                       ViInt32 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmy_reset (ViSession instrSession);
ViStatus _VI_FUNC rssmy_self_test (ViSession instrSession,
                                   ViPInt16 testResult,
                                   ViChar _VI_FAR testMessage[]);
ViStatus _VI_FUNC rssmy_diagnostics (ViSession instrSession,
                                     ViInt32 testpoint117, ViBoolean testState,
                                     ViPReal64 reading);
ViStatus _VI_FUNC rssmy_revision_query (ViSession instrSession,
                                        ViChar _VI_FAR driverRev[],
                                        ViChar _VI_FAR instrRev[]);
ViStatus _VI_FUNC rssmy_error_query (ViSession instrSession, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmy_error_message (ViSession instrSession,
                                       ViStatus statusCode,
                                       ViChar _VI_FAR errMessage[]);
ViStatus _VI_FUNC rssmy_checkStatus (ViSession instrSession,
                                     ViBoolean checkForStatus);
ViStatus _VI_FUNC rssmy_close (ViSession instrSession);

#if defined (__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
